FileMetadata

Struct FileMetadata 

pub struct FileMetadata {
Show 19 fields pub created: String, pub modified: String, pub accessed: String, pub size_in_bytes: u64, pub is_file_read_only: bool, pub is_dir: bool, pub is_file: bool, pub is_symlink: bool, pub is_readable: bool, pub is_writable: bool, pub is_executable: bool, pub dev: u64, pub ino: u64, pub mode: u32, pub nlink: u64, pub uid: u32, pub gid: u32, pub blksize: u64, pub blocks: u64, /* private fields */
}

Fields

created: Stringmodified: Stringaccessed: Stringsize_in_bytes: u64is_file_read_only: boolis_dir: boolis_file: boolis_symlink: boolis_readable: boolis_writable: boolis_executable: booldev: u64ino: u64mode: u32nlink: u64uid: u32gid: u32blksize: u64blocks: u64

Implementations

Source

impl FileMetadata

Methods for FileMetadata, providing functionality to create a new instance from a file path, retrieve file metadata, and access file size information.

Fields

Cross-platform
  • created, modified, accessed — date strings (YYYY-MM-DD)
  • size_in_bytes — raw file size in bytes
  • is_file_read_only, is_dir, is_file, is_symlink — file type flags
  • is_readable, is_writable, is_executable — permission checks
Unix only (#[cfg(unix)])
  • dev — device ID
  • ino — inode number
  • mode — full permission bits (octal)
  • nlink — hard link count
  • uid, gid — owner/group IDs
  • blksize, blocks — filesystem block size and allocated 512-byte blocks
Windows only (#[cfg(windows)])
  • file_attributes — Windows attribute flags (hidden, system, archive, etc.)
  • creation_time, last_write_time, last_access_time — raw FILETIME values

Methods

  • new(path: &Path) -> Result<Self, String> — construct from a file path
  • readable(&self) -> bool — whether the file is readable
  • writable(&self) -> bool — whether the file is writable
  • executable(&self) -> bool — whether the file is executable
  • get_file_in_kilobytes(&self) -> f32 — file size in KB
  • get_file_in_megabytes(&self) -> f32 — file size in MB
  • get_file_in_gigabytes(&self) -> f32 — file size in GB
  • get_file_in_terabytes(&self) -> f32 — file size in TB
pub fn new(path: &Path) -> Result<Self, String>

pub fn readable(&self) -> bool

pub fn writable(&self) -> bool

pub fn executable(&self) -> bool

pub fn get_file_in_kilobytes(&self) -> f32

pub fn get_file_in_megabytes(&self) -> f32

pub fn get_file_in_gigabytes(&self) -> f32

pub fn get_file_in_terabytes(&self) -> f32